"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const notionLoader_1 = require("../notion/notionLoader");
const loadPage_1 = require("../notion/loadPage");
const createNodeForPage_1 = require("./createNodeForPage");
const downloadNotionImages_1 = require("../gatsby/downloadNotionImages");
async function createNodesFromRootPage(rootPageId, createNodeId, createNode, createContentDigest, getNodes, store, cache, pluginConfig, reporter) {
    try {
        const { debug } = pluginConfig;
        const loader = notionLoader_1.default(reporter, debug);
        // loading the root page
        const item = await loadPage_1.default(rootPageId, '', 0, loader, reporter);
        // we are interested only by the linked pages from the root page
        let index = 0;
        for (const linkedPage of item.linkedPages) {
            index += 1;
            const { pageId, title } = linkedPage;
            // we reset data before we load a new page
            // (to avoid keeping around too many blocks)
            loader.reset();
            await createNodeForPage_1.default(pageId, rootPageId, title, index, loader, createNodeId, createNode, createContentDigest, pluginConfig, reporter);
        }
        // we download all the images found
        // in the various pages
        await downloadNotionImages_1.default(getNodes, createNode, createNodeId, store, cache, createContentDigest, loader, pluginConfig, reporter);
    }
    catch (err) {
        reporter.error(`Error loading root page: ${rootPageId} - error is: ${err.message}`);
    }
}
exports.default = createNodesFromRootPage;
//# sourceMappingURL=createNodesFromRootPage.js.map