"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gatsby_source_filesystem_1 = require("gatsby-source-filesystem");
// reference:
// https://www.gatsbyjs.org/packages/gatsby-source-filesystem/#createremotefilenode
async function downloadNotionImages(getNodes, createNode, createNodeId, store, cache, createContentDigest, notionLoader, pluginConfig, reporter) {
    const imagesNodes = getNodes().filter((n) => {
        return n.internal && n.internal.owner === 'gatsby-source-notionso';
    });
    const imagesToDownload = [];
    await Promise.all(imagesNodes.map(async (node) => {
        (node.images || []).forEach(image => {
            imagesToDownload.push([image.notionUrl, image.contentId, image.pageId]);
        });
    }));
    const result = await notionLoader.downloadImages(imagesToDownload);
    reporter.info(`Images for notion source: ${result}`);
    for (const img of result) {
        const [notionUrl, signedUrl, pageId] = img;
        const fileNode = await gatsby_source_filesystem_1.createRemoteFileNode({
            url: signedUrl,
            store,
            cache,
            createNode,
            createNodeId,
            reporter,
        });
        const assetNodeId = createNodeId(notionUrl);
        const item = {
            notionUrl,
            pageId,
            // eslint-disable-next-line @typescript-eslint/camelcase
            localFile___NODE: fileNode.id,
        };
        createNode(Object.assign(Object.assign({}, item), { id: assetNodeId, _id: assetNodeId, parent: undefined, children: [], internal: {
                contentDigest: createContentDigest(item),
                type: `NotionPageAsset${pluginConfig.name}`,
            } }));
    }
}
exports.default = downloadNotionImages;
//# sourceMappingURL=downloadNotionImages.js.map